==> spip_2.0.8.orig.tar.gz: spip-2.0.8.orig/ecrire/lang/public_id.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Halaman Depan',
'articles' => 'Artikel-artikel',
'articles_auteur' => 'Artikel-artikel penulis ini',
'articles_populaires' => 'Artikel-artikel yang paling banyak dibaca',
'articles_rubrique' => 'Artikel-artikel bagian ini',
'aucun_article' => 'Tidak ada artikel di alamat ini',
'aucun_auteur' => 'Tidak ada penulis di alamat ini',
'aucun_site' => 'Tidak ada situs di alamat ini',
'aucune_breve' => 'Tidak ada berita di alamat ini',
'aucune_rubrique' => 'Tidak ada bagian di alamat ini',
'autres_breves' => 'Berita lainnya',
'autres_groupes_mots_clefs' => 'Kelompok-kelompok kata kunci lainnya',
'autres_sites' => 'Situs-situs lainnya',

// B
'bonjour' => 'Halo',
'breves' => 'Artikel-artikel berita',

// C
'commenter_site' => 'Komentar di situs ini',

// D
'date' => 'Tanggal',
'dernier_ajout' => 'Penambahan terbaru',
'dernieres_breves' => 'Berita terbaru',
'derniers_articles' => 'Artikel-artikel terbaru',
'derniers_commentaires' => 'Komentar-komentar terbaru',
'derniers_messages_forum' => 'Pesan-pesan terbaru yang dipublikasikan di forum ini',

// E
'edition_mode_texte' => 'Tampilan teks saja',
'en_reponse' => 'Membalas kepada:',
'en_resume' => 'Ringkasan',
'envoyer_message' => 'Untuk mengirimkan sebuah pesan',
'espace_prive' => 'Area pribadi',

// F
'forum' => 'Forum',

// H
'hierarchie_site' => 'Hirarki situs',

// J
'jours' => 'hari',

// M
'meme_auteur' => 'Oleh penulis yang sama',
'meme_rubrique' => 'Dalam bagian yang sama',
'memes_auteurs' => 'Oleh penulis-penulis yang sama',
'message' => 'Pesan',
'messages_forum' => 'Pesan-pesan forum',
'messages_recents' => 'Pesan-pesan forum terbaru',
'mots_clefs' => 'Kata-kata kunci',
'mots_clefs_meme_groupe' => 'Kata-kata kunci dalam kelompok yang sama',

// N
'navigation' => 'Navigasi',
'nom' => 'Nama',
'nouveautes' => 'Yang terbaru',
'nouveautes_web' => 'Yang terbaru di dunia Web',
'nouveaux_articles' => 'Artikel-artikel baru',
'nouvelles_breves' => 'Berita-berita baru',

// P
'page_precedente' => 'halaman sebelumnya',
'page_suivante' => 'halaman selanjutnya',
'par_auteur' => 'oleh ',
'participer_site' => 'Anda dapat berpartisipasi secara aktif di situs web ini dan menulis artikel anda sendiri dengan sebelumnya mendaftarkan diri di bawah ini. Anda akan menerima segera sebuah e-mail yang berisikan kode akses ke area pribadi situs ini.',
'plan_site' => 'Peta Situs',
'popularite' => 'Popularitas',
'poster_message' => 'Untuk mengirimkan sebuah pesan',
'proposer_site' => 'Anda dapat merekomendasikan sebuah situs untuk ditambahkan ke dalam bagian ini:',

// R
'repondre_article' => 'Balasan pada artikel ini',
'repondre_breve' => 'Balasan pada artikel berita ini',
'repondre_message' => 'Balasan pada pesan ini',
'resultats_recherche' => 'Hasil pencarian',
'retour_debut_forums' => 'Kembali ke awal forum',
'rubrique' => 'Bagian',
'rubriques' => 'Bagian',

// S
'signatures_petition' => 'Tanda tangan',
'site_realise_avec_spip' => 'Situs dibuat dengan SPIP',
'sites_web' => 'Situs-situs web',
'sous_rubriques' => 'Sub-sub bagian',
'suite' => 'lanjut',
'sur_web' => 'Di Web',
'syndiquer_rubrique' => 'Sindikasi bagian ini',
'syndiquer_site' => 'Sindikasi seluruh isi situs',

// T
'texte_lettre_information' => 'Berikut adalah laporan berkala situs',
'texte_lettre_information_2' => 'Laporan ini memberikan ringkasan artikel-artikel dan berita-berita yang dipublikasikan sejak',

// V
'ver_imprimer' => 'Versi cetak',
'voir_en_ligne' => 'Lihat secara online',
'voir_squelette' => '&#1613;Tampilkan templat halaman ini'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_id.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Halaman Depan',
'article' => 'Article', # NEW
'articles' => 'Artikel-artikel',
'articles_auteur' => 'Artikel-artikel penulis ini',
'articles_populaires' => 'Artikel-artikel yang paling banyak dibaca',
'articles_rubrique' => 'Artikel-artikel bagian ini',
'aucun_article' => 'Tidak ada artikel di alamat ini',
'aucun_auteur' => 'Tidak ada penulis di alamat ini',
'aucun_site' => 'Tidak ada situs di alamat ini',
'aucune_breve' => 'Tidak ada berita di alamat ini',
'aucune_rubrique' => 'Tidak ada bagian di alamat ini',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => 'Berita lainnya',
'autres_groupes_mots_clefs' => 'Kelompok-kelompok kata kunci lainnya',
'autres_sites' => 'Situs-situs lainnya',

// B
'bonjour' => 'Halo',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Artikel-artikel berita',

// C
'commenter_site' => 'Komentar di situs ini',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => 'Tanggal',
'dernier_ajout' => 'Penambahan terbaru',
'dernieres_breves' => 'Berita terbaru',
'derniers_articles' => 'Artikel-artikel terbaru',
'derniers_commentaires' => 'Komentar-komentar terbaru',
'derniers_messages_forum' => 'Pesan-pesan terbaru yang dipublikasikan di forum ini',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'Tampilan teks saja',
'en_reponse' => 'Membalas kepada:',
'en_resume' => 'Ringkasan',
'envoyer_message' => 'Untuk mengirimkan sebuah pesan',
'espace_prive' => 'Area pribadi',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'Forum',

// H
'hierarchie_site' => 'Hirarki situs',

// J
'jours' => 'hari',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'Oleh penulis yang sama',
'meme_rubrique' => 'Dalam bagian yang sama',
'memes_auteurs' => 'Oleh penulis-penulis yang sama',
'message' => 'Pesan',
'messages_forum' => 'Pesan-pesan forum',
'messages_recents' => 'Pesan-pesan forum terbaru',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Kata-kata kunci',
'mots_clefs_meme_groupe' => 'Kata-kata kunci dalam kelompok yang sama',

// N
'navigation' => 'Navigasi',
'nom' => 'Nama',
'nouveautes' => 'Yang terbaru',
'nouveautes_web' => 'Yang terbaru di dunia Web',
'nouveaux_articles' => 'Artikel-artikel baru',
'nouvelles_breves' => 'Berita-berita baru',

// P
'page_precedente' => 'halaman sebelumnya',
'page_suivante' => 'halaman selanjutnya',
'par_auteur' => 'oleh ',
'participer_site' => 'Anda dapat berpartisipasi secara aktif di situs web ini dan menulis artikel anda sendiri dengan sebelumnya mendaftarkan diri di bawah ini. Anda akan menerima segera sebuah e-mail yang berisikan kode akses ke area pribadi situs ini.',
'plan_site' => 'Peta Situs',
'popularite' => 'Popularitas',
'poster_message' => 'Untuk mengirimkan sebuah pesan',
'proposer_site' => 'Anda dapat merekomendasikan sebuah situs untuk ditambahkan ke dalam bagian ini:',

// R
'repondre_article' => 'Balasan pada artikel ini',
'repondre_breve' => 'Balasan pada artikel berita ini',
'repondre_message' => 'Balasan pada pesan ini',
'resultats_recherche' => 'Hasil pencarian',
'retour_debut_forums' => 'Kembali ke awal forum',
'rubrique' => 'Bagian',
'rubriques' => 'Bagian',

// S
'signatures_petition' => 'Tanda tangan',
'site_realise_avec_spip' => 'Situs dibuat dengan SPIP',
'sites_web' => 'Situs-situs web',
'sous_rubriques' => 'Sub-sub bagian',
'spam' => 'Spam', # NEW
'suite' => 'lanjut',
'sur_web' => 'Di Web',
'syndiquer_rubrique' => 'Sindikasi bagian ini',
'syndiquer_site' => 'Sindikasi seluruh isi situs',

// T
'texte_lettre_information' => 'Berikut adalah laporan berkala situs',
'texte_lettre_information_2' => 'Laporan ini memberikan ringkasan artikel-artikel dan berita-berita yang dipublikasikan sejak',

// V
'ver_imprimer' => 'Versi cetak',
'voir_en_ligne' => 'Lihat secara online',
'voir_squelette' => '&#1613;Tampilkan templat halaman ini'
);

?>
